@@ -25,52 +25,52 @@ class Parser():
 
         colorama.init()
 
-        if (self.count > 0) and (self.arguments is not None):
+        if (self.count > 0) and (self.arguments != None):
 
-            print("Count:{0} ".format(self.count) , end = '')
+            print("Count:{0} ".format(self.count) , end='')
 
             for arg in self.arguments:
-                print("/ {0} ".format(arg), end = '')
+                print("/ {0} ".format(arg), end='')
 
             print("")
 
-            # > python -m e_drone upgrade
-            # > python -m e_drone update
+            # >python -m e_drone upgrade
+            # >python -m e_drone update
             if      (self.arguments[0] == "upgrade") or (self.arguments[0] == "update"):
                 updater = Updater()
                 updater.update()
                 return
 
-            # > python -m e_drone request State 10 0.2
+            # >python -m e_drone request State 10 0.2
             elif    ((self.count == 4) and 
                     (self.arguments[0] == "request") and
                     (self.arguments[1] == "state")):         # time interval
-                #print("* State - Ready     Blue    Red     Black   Black   NONE             1830   1631   2230      76      ")    
+                #print("* State - Ready     Blue    Red     Black   Black   None_             1830   1631   2230      76      ")    
                 print ("         |ModeSystem   |ModeFlight |ModeControlFlight |ModeMovement |Headless |ControlSpeed |SensorOrientation |Battery |")
-                self.send_request(DeviceType.DRONE, DataType.STATE, int(self.arguments[2]), float(self.arguments[3]))
+                self.request(DeviceType.Drone, DataType.State, int(self.arguments[2]), float(self.arguments[3]))
                 return
 
-            # > python -m e_drone request Motion 10 0.2
+            # >python -m e_drone request Motion 10 0.2
             elif    ((self.count == 4) and 
                     (self.arguments[0] == "request") and
                     (self.arguments[1] == "motion")):         # time interval
                 #print("* Motion      -38      64     -32     457     -40    -400      16       0   20500")    
                 print ("         |Accel                  |Gyro                   |Angle                  |")
                 print ("         |      X|      Y|      Z|   Roll|  Pitch|    Yaw|   Roll|  Pitch|    Yaw|")
-                self.send_request(DeviceType.DRONE, DataType.MOTION, int(self.arguments[2]), float(self.arguments[3]))
+                self.request(DeviceType.Drone, DataType.Motion, int(self.arguments[2]), float(self.arguments[3]))
                 return
 
-            # > python -m e_drone request CardRaw 10 0.2
+            # >python -m e_drone request CardRaw 10 0.2
             elif    ((self.count == 4) and 
                     (self.arguments[0] == "request") and
                     (self.arguments[1] == "cardraw")):         # time interval
                 #print("* CardRaw   335  503  766  692  309  395 100  39  96  40   9  17 303  61  39 344  77  15   Magenta         Red")
                 print ("          |Front Raw     |Rear Raw      |Front RGB  |Rear RGB   |Front HSVL      |Rear HSVL       |Front Color  |Rear Color   |")
                 print ("          |   R    G    B|   R    G    B|  R   G   B|  R   G   B|  H   S   V   L|  H   S   V   L|             |             |")
-                self.send_request(DeviceType.DRONE, DataType.CARD_RAW, int(self.arguments[2]), float(self.arguments[3]))
+                self.request(DeviceType.Drone, DataType.CardRaw, int(self.arguments[2]), float(self.arguments[3]))
                 return
 
-            # > python -m e_drone request CardRange 10 0.2
+            # >python -m e_drone request CardRange 10 0.2
             elif    ((self.count == 4) and 
                     (self.arguments[0] == "request") and
                     (self.arguments[1] == "cardrange")):         # time interval
@@ -78,7 +78,7 @@ class Parser():
                 print ("               |Front                              |Rear                               |")
                 print ("               |Red        |Green      |Blue       |Red        |Green      |Blue       |")
                 print ("               |  Min|  Max|  Min|  Max|  Min|  Max|  Min|  Max|  Min|  Max|  Min|  Max|")
-                self.send_request(DeviceType.DRONE, DataType.CARD_RANGE, int(self.arguments[2]), float(self.arguments[3]))
+                self.request(DeviceType.Drone, DataType.CardRange, int(self.arguments[2]), float(self.arguments[3]))
                 return
 
             # 이륙
@@ -87,7 +87,7 @@ class Parser():
             elif    ((self.count == 1) and 
                     (self.arguments[0] == "takeoff")):
                 print (Fore.YELLOW + "takeoff" + Style.RESET_ALL)
-                self.send_flight_event(FlightEvent.TAKEOFF)
+                self.command(CommandType.FlightEvent, FlightEvent.TakeOff.value)
                 return
 
             # 착륙
@@ -96,7 +96,7 @@ class Parser():
             elif    ((self.count == 1) and 
                     (self.arguments[0] == "landing")):
                 print (Fore.YELLOW + "landing" + Style.RESET_ALL)
-                self.send_flight_event(FlightEvent.LANDING)
+                self.command(CommandType.FlightEvent, FlightEvent.Landing.value)
                 return
 
             # 정지
@@ -105,18 +105,18 @@ class Parser():
             elif    ((self.count == 1) and 
                     (self.arguments[0] == "stop")):
                 print (Fore.YELLOW + "stop" + Style.RESET_ALL)
-                self.send_flight_event(FlightEvent.STOP)
+                self.command(CommandType.FlightEvent, FlightEvent.Stop.value)
                 return
 
             # 조종
             #                   0        1      2       3     4          5
             # python -m e_drone control [roll] [pitch] [yaw] [throttle] [time(ms)]
             # 지정한 시간이 종료되면 입력값을 모두 0으로 변경하고 멈춤
-            # > python -m e_drone control 40 0 3
+            # >python -m e_drone control 40 0 3
             elif    ((self.count == 6) and 
                     (self.arguments[0] == "control")):
                 print (Fore.YELLOW + "control" + Style.RESET_ALL)
-                self.send_control(int(self.arguments[1]), int(self.arguments[2]), int(self.arguments[3]), int(self.arguments[4]), int(self.arguments[5]))
+                self.control(int(self.arguments[1]), int(self.arguments[2]), int(self.arguments[3]), int(self.arguments[4]), int(self.arguments[5]))
                 return
 
             # 이동(전체)
@@ -125,7 +125,7 @@ class Parser():
             elif    ((self.count == 7) and 
                     (self.arguments[0] == "position")):
                 print (Fore.YELLOW + "position" + Style.RESET_ALL)
-                self.send_control_position(float(self.arguments[1]), float(self.arguments[2]), float(self.arguments[3]), float(self.arguments[4]), float(self.arguments[5]), float(self.arguments[6]))
+                self.controlPosition(float(self.arguments[1]), float(self.arguments[2]), float(self.arguments[3]), float(self.arguments[4]), float(self.arguments[5]), float(self.arguments[6]))
                 return
 
             # 이동(위치)
@@ -134,7 +134,7 @@ class Parser():
             elif    ((self.count == 5) and 
                     (self.arguments[0] == "position")):
                 print (Fore.YELLOW + "position" + Style.RESET_ALL)
-                self.send_control_position(float(self.arguments[1]), float(self.arguments[2]), float(self.arguments[3]), float(self.arguments[4]), 0, 0)
+                self.controlPosition(float(self.arguments[1]), float(self.arguments[2]), float(self.arguments[3]), float(self.arguments[4]), 0, 0)
                 return
 
             # 이동(헤딩)
@@ -143,59 +143,59 @@ class Parser():
             elif    ((self.count == 3) and 
                     (self.arguments[0] == "heading")):
                 print (Fore.YELLOW + "heading" + Style.RESET_ALL)
-                self.send_control_position(0, 0, 0, 0, float(self.arguments[1]), float(self.arguments[2]))
+                self.controlPosition(0, 0, 0, 0, float(self.arguments[1]), float(self.arguments[2]))
                 return
 
             # 버저
             #                   1       2    3
             # python -m e_drone buzzer [hz] [time(ms)]
-            # > python -m e_drone buzzer 400 2000
+            # >python -m e_drone buzzer 400 2000
             elif    ((self.count == 3) and 
                     (self.arguments[0] == "buzzer")):
                 print (Fore.WHITE + "Buzz Sound: " + Fore.YELLOW + "{0}".format(int(self.arguments[1])) + Fore.WHITE + "Hz, " + Fore.CYAN + "{0}".format(int(self.arguments[2])) + Fore.WHITE + "ms" + Style.RESET_ALL)
-                self.send_buzzer(DeviceType.CONTROLLER, int(self.arguments[1]), int(self.arguments[2]))
+                self.buzzer(DeviceType.Controller, int(self.arguments[1]), int(self.arguments[2]))
                 return
 
             # 진동
             #                   1         2          3           4
             # python -m e_drone vibrator [on(ms)] [off(ms)] [total(ms)]
-            # > python -m e_drone vibrator 500 500 2000
+            # >python -m e_drone vibrator 500 500 2000
             elif    ((self.count == 4) and 
                     (self.arguments[0] == "vibrator")):
                 print (Fore.WHITE + "Vibrator: on " + Fore.YELLOW + "{0}".format(int(self.arguments[1])) + Fore.WHITE + "ms, off " + Fore.CYAN + "{0}".format(int(self.arguments[2])) + Fore.WHITE + "ms, total " + Fore.CYAN + "{0}".format(int(self.arguments[3])) + Fore.WHITE + "ms" + Style.RESET_ALL)
-                self.send_vibrator(DeviceType.CONTROLLER, int(self.arguments[1]), int(self.arguments[2]), int(self.arguments[3]))
+                self.vibrator(DeviceType.Controller, int(self.arguments[1]), int(self.arguments[2]), int(self.arguments[3]))
                 return
 
 
-            # > python -m e_drone light body flicker 100 50 50 10
-            # > python -m e_drone light body flickerdouble 100 50 50 10
-            # > python -m e_drone light body dimming 3 50 50 10
-            # > python -m e_drone light body sunrise 5 50 50 10
-            # > python -m e_drone light body sunset 5 50 50 10
-            # > python -m e_drone light body rainbow 8 50 50 10
-            # > python -m e_drone light body rainbow2 8 50 50 10
+            # >python -m e_drone light body flicker 100 50 50 10
+            # >python -m e_drone light body flickerdouble 100 50 50 10
+            # >python -m e_drone light body dimming 3 50 50 10
+            # >python -m e_drone light body sunrise 5 50 50 10
+            # >python -m e_drone light body sunset 5 50 50 10
+            # >python -m e_drone light body rainbow 8 50 50 10
+            # >python -m e_drone light body rainbow2 8 50 50 10
             elif    ((self.count == 7) and 
                     (self.arguments[0] == "light")):
                 print (Fore.WHITE + "Light: " + Fore.YELLOW + "{0}, {1}, {2}, ({3}, {4}, {5})".format(self.arguments[1], self.arguments[2], int(self.arguments[3]), int(self.arguments[4]), int(self.arguments[5]), int(self.arguments[6])) + Style.RESET_ALL)
-                self.send_light_mode_color(self.arguments[1], self.arguments[2], int(self.arguments[3]), int(self.arguments[4]), int(self.arguments[5]), int(self.arguments[6]))
+                self.lightModeRgb(self.arguments[1], self.arguments[2], int(self.arguments[3]), int(self.arguments[4]), int(self.arguments[5]), int(self.arguments[6]))
                 return
 
-            # > python -m e_drone light front hold 100
-            # > python -m e_drone light head hold 100
-            # > python -m e_drone light tail hold 100
-            # > python -m e_drone light left hold 100
-            # > python -m e_drone light right hold 100
+            # >python -m e_drone light front hold 100
+            # >python -m e_drone light head hold 100
+            # >python -m e_drone light tail hold 100
+            # >python -m e_drone light left hold 100
+            # >python -m e_drone light right hold 100
             elif    ((self.count == 4) and 
                     (self.arguments[0] == "light")):
                 print (Fore.WHITE + "Light: " + Fore.YELLOW + "{0}, {1}, {2}".format(self.arguments[1], self.arguments[2], int(self.arguments[3])) + Style.RESET_ALL)
-                self.send_light_mode_single(self.arguments[1], self.arguments[2], int(self.arguments[3]))
+                self.lightModeSingle(self.arguments[1], self.arguments[2], int(self.arguments[3]))
                 return
 
         # 아무것도 실행되지 않은 경우
         self.help()
 
 
-    def send_request(self, device_type, data_type, repeat, interval):
+    def request(self, deviceType, dataType, repeat, interval):
 
         #drone = Drone(True, True, True, True, True)
         drone = Drone()
@@ -204,18 +204,18 @@ class Parser():
             sys.exit(1)
         
         # 이벤트 핸들링 함수 등록
-        drone.set_event_handler(DataType.STATE, self.event_state)
-        drone.set_event_handler(DataType.MOTION, self.event_motion)
-        drone.set_event_handler(DataType.CARD_RAW, self.event_card_raw)
-        drone.set_event_handler(DataType.CARD_RANGE, self.event_card_range)
+        drone.setEventHandler(DataType.State, self.eventState)
+        drone.setEventHandler(DataType.Motion, self.eventMotion)
+        drone.setEventHandler(DataType.CardRaw, self.eventCardRaw)
+        drone.setEventHandler(DataType.CardRange, self.eventCardRange)
 
         # 데이터 요청
         for i in range(repeat):
-            drone.send_request(device_type, data_type)
+            drone.sendRequest(deviceType, dataType)
             sleep(interval)
 
 
-    def send_command(self, device_type, command_type, option = 0):
+    def command(self, commandType, option = 0):
 
         #drone = Drone(True, True, True, True, True)
         drone = Drone()
@@ -224,10 +224,10 @@ class Parser():
             sys.exit(1)
 
         # 데이터 요청
-        drone.send_command(device_type, command_type, option);
+        drone.sendCommand(commandType, option);
 
 
-    def send_flight_event(self, flight_event):
+    def control(self, roll, pitch, yaw, throttle, timeMs):
 
         #drone = Drone(True, True, True, True, True)
         drone = Drone()
@@ -236,10 +236,11 @@ class Parser():
             sys.exit(1)
 
         # 데이터 요청
-        drone.send_flight_event(flight_event);
+        drone.sendControlWhile(roll, pitch, yaw, throttle, timeMs)
+        drone.sendControlWhile(0, 0, 0, 0, 200)
 
 
-    def send_control(self, roll, pitch, yaw, throttle, time_ms):
+    def controlPosition(self, x, y, z, velocity, heading, rotationalVelocity):
 
         #drone = Drone(True, True, True, True, True)
         drone = Drone()
@@ -248,24 +249,11 @@ class Parser():
             sys.exit(1)
 
         # 데이터 요청
-        drone.send_control_time(roll, pitch, yaw, throttle, time_ms)
-        drone.send_control_time(0, 0, 0, 0, 200)
-
-
-    def send_control_position(self, x, y, z, velocity, heading, rotational_velocity):
-
-        #drone = Drone(True, True, True, True, True)
-        drone = Drone()
-        if drone.open() == False:
-            print(Fore.RED + "* Error : Unable to open serial port." + Style.RESET_ALL)
-            sys.exit(1)
-
-        # 데이터 요청
-        drone.send_control_position(x, y, z, velocity, heading, rotational_velocity)
+        drone.sendControlPosition(x, y, z, velocity, heading, rotationalVelocity)
         sleep(0.1)
 
 
-    def send_light_mode_color(self, str_light_part, str_light_mode, interval, r, g, b):
+    def lightModeRgb(self, strLightPart, strLightMode, interval, r, g, b):
 
         #drone = Drone(True, True, True, True, True)
         drone = Drone()
@@ -279,43 +267,43 @@ class Parser():
             (not isinstance(b, int)) ):
             return None
 
-        light_mode_high = LightModeDrone.NONE
+        lightModeHigh = LightModeDrone.None_
 
-        if      str_light_part == "rear":
-            light_mode_high = LightModeDrone.REAR_NONE
-        elif    str_light_part == "body":
-            light_mode_high = LightModeDrone.BODY_NONE
-        elif    str_light_part == "a":
-            light_mode_high = LightModeDrone.A_NONE
-        elif    str_light_part == "b":
-            light_mode_high = LightModeDrone.B_NONE
+        if      strLightPart == "rear":
+            lightModeHigh = LightModeDrone.RearNone
+        elif    strLightPart == "body":
+            lightModeHigh = LightModeDrone.BodyNone
+        elif    strLightPart == "a":
+            lightModeHigh = LightModeDrone.ANone
+        elif    strLightPart == "b":
+            lightModeHigh = LightModeDrone.BNone
 
-        light_mode_low = LightModeDrone.NONE
+        lightModeLow = LightModeDrone.None_
 
-        if      str_light_mode == "hold":
-            light_mode_low = LightModeDrone.BODY_HOLD
-        elif    str_light_mode == "flicker":
-            light_mode_low = LightModeDrone.BODY_FLICKER
-        elif    str_light_mode == "flickerdouble":
-            light_mode_low = LightModeDrone.BODY_FLICKER_DOUBLE
-        elif    str_light_mode == "dimming":
-            light_mode_low = LightModeDrone.BODY_DIMMING
-        elif    str_light_mode == "sunrise":
-            light_mode_low = LightModeDrone.BODY_SUNRISE
-        elif    str_light_mode == "sunset":
-            light_mode_low = LightModeDrone.BODY_SUNSET
-        elif    str_light_mode == "rainbow":
-            light_mode_low = LightModeDrone.BODY_RAINBOW
-        elif    str_light_mode == "rainbow2":
-            light_mode_low = LightModeDrone.BODY_RAINBOW2
+        if      strLightMode == "hold":
+            lightModeLow = LightModeDrone.BodyHold
+        elif    strLightMode == "flicker":
+            lightModeLow = LightModeDrone.BodyFlicker
+        elif    strLightMode == "flickerdouble":
+            lightModeLow = LightModeDrone.BodyFlickerDouble
+        elif    strLightMode == "dimming":
+            lightModeLow = LightModeDrone.BodyDimming
+        elif    strLightMode == "sunrise":
+            lightModeLow = LightModeDrone.BodySunrise
+        elif    strLightMode == "sunset":
+            lightModeLow = LightModeDrone.BodySunset
+        elif    strLightMode == "rainbow":
+            lightModeLow = LightModeDrone.BodyRainbow
+        elif    strLightMode == "rainbow2":
+            lightModeLow = LightModeDrone.BodyRainbow2
 
-        light_mode = LightModeDrone(light_mode_high.value + ((light_mode_low.value) & 0x0F))
+        lightMode = LightModeDrone(lightModeHigh.value + ((lightModeLow.value) & 0x0F))
 
-        if light_mode_high != LightModeDrone.NONE and light_mode_low != LightModeDrone.NONE:
-            drone.send_light_mode_color(DeviceType.DRONE, light_mode, interval, r, g, b)
+        if lightModeHigh != LightModeDrone.None_ and lightModeLow != LightModeDrone.None_:
+            drone.sendLightModeColor(lightMode, interval, r, g, b)
 
 
-    def send_light_mode_single(self, str_light_part, str_light_mode, interval):
+    def lightModeSingle(self, strLightPart, strLightMode, interval):
 
         #drone = Drone(True, True, True, True, True)
         drone = Drone()
@@ -326,43 +314,43 @@ class Parser():
         if ( (not isinstance(interval, int)) ):
             return None
 
-        light_mode_high = LightModeDrone.NONE
+        lightModeHigh = LightModeDrone.None_
 
-        if      str_light_part == "rear":
-            light_mode_high = LightModeDrone.REAR_NONE
-        elif    str_light_part == "body":
-            light_mode_high = LightModeDrone.BODY_NONE
-        elif    str_light_part == "a":
-            light_mode_high = LightModeDrone.A_NONE
-        elif    str_light_part == "b":
-            light_mode_high = LightModeDrone.B_NONE
+        if      strLightPart == "rear":
+            lightModeHigh = LightModeDrone.RearNone
+        elif    strLightPart == "body":
+            lightModeHigh = LightModeDrone.BodyNone
+        elif    strLightPart == "a":
+            lightModeHigh = LightModeDrone.ANone
+        elif    strLightPart == "b":
+            lightModeHigh = LightModeDrone.BNone
 
-        light_mode_low = LightModeDrone.NONE
+        lightModeLow = LightModeDrone.None_
 
-        if      str_light_mode == "hold":
-            light_mode_low = LightModeDrone.BODY_HOLD
-        elif    str_light_mode == "flicker":
-            light_mode_low = LightModeDrone.BODY_FLICKER
-        elif    str_light_mode == "flickerdouble":
-            light_mode_low = LightModeDrone.BODY_FLICKER_DOUBLE
-        elif    str_light_mode == "dimming":
-            light_mode_low = LightModeDrone.BODY_DIMMING
-        elif    str_light_mode == "sunrise":
-            light_mode_low = LightModeDrone.BODY_SUNRISE
-        elif    str_light_mode == "sunset":
-            light_mode_low = LightModeDrone.BODY_SUNSET
-        elif    str_light_mode == "rainbow":
-            light_mode_low = LightModeDrone.BODY_RAINBOW
-        elif    str_light_mode == "rainbow2":
-            light_mode_low = LightModeDrone.BODY_RAINBOW2
+        if      strLightMode == "hold":
+            lightModeLow = LightModeDrone.BodyHold
+        elif    strLightMode == "flicker":
+            lightModeLow = LightModeDrone.BodyFlicker
+        elif    strLightMode == "flickerdouble":
+            lightModeLow = LightModeDrone.BodyFlickerDouble
+        elif    strLightMode == "dimming":
+            lightModeLow = LightModeDrone.BodyDimming
+        elif    strLightMode == "sunrise":
+            lightModeLow = LightModeDrone.BodySunrise
+        elif    strLightMode == "sunset":
+            lightModeLow = LightModeDrone.BodySunset
+        elif    strLightMode == "rainbow":
+            lightModeLow = LightModeDrone.BodyRainbow
+        elif    strLightMode == "rainbow2":
+            lightModeLow = LightModeDrone.BodyRainbow2
 
-        light_mode = LightModeDrone(light_mode_high.value + ((light_mode_low.value) & 0x0F))
+        lightMode = LightModeDrone(lightModeHigh.value + ((lightModeLow.value) & 0x0F))
 
-        if light_mode_high != LightModeDrone.NONE and light_mode_low != LightModeDrone.NONE:
-            drone.send_light_mode(DeviceType.DRONE, light_mode, interval)
+        if lightModeHigh != LightModeDrone.None_ and lightModeLow != LightModeDrone.None_:
+            drone.sendLightMode(lightMode, interval)
 
 
-    def send_buzzer(self, target, hz, time):
+    def buzzer(self, target, hz, time):
 
         #drone = Drone(True, True, True, True, True)
         drone = Drone()
@@ -375,14 +363,14 @@ class Parser():
 
         header = Header()
         
-        header.data_type = DataType.BUZZER
-        header.length   = Buzzer.get_size()
-        header.from_    = DeviceType.BASE
+        header.dataType = DataType.Buzzer
+        header.length   = Buzzer.getSize()
+        header.from_    = DeviceType.Base
         header.to_      = target
         
         data = Buzzer()
 
-        data.mode       = BuzzerMode.HZ
+        data.mode       = BuzzerMode.Hz
         data.value      = hz
         data.time       = time
 
@@ -390,7 +378,7 @@ class Parser():
         sleep(time / 1000)
 
 
-    def send_vibrator(self, target, on, off, total):
+    def vibrator(self, target, on, off, total):
 
         #drone = Drone(True, True, True, True, True)
         drone = Drone()
@@ -403,14 +391,14 @@ class Parser():
 
         header = Header()
         
-        header.data_type = DataType.VIBRATOR
-        header.length    = Vibrator.get_size()
-        header.from_     = DeviceType.BASE
-        header.to_       = target
+        header.dataType = DataType.Vibrator
+        header.length   = Vibrator.getSize()
+        header.from_    = DeviceType.Base
+        header.to_      = target
         
         data = Vibrator()
 
-        data.mode       = VibratorMode.INSTANTLY
+        data.mode       = VibratorMode.Instantally
         data.on         = on
         data.off        = off
         data.total      = total
@@ -495,77 +483,77 @@ class Parser():
         print("")
 
 
-    def event_state(self, state):
+    def eventState(self, state):
 
         print(  "* State   " +
-                Fore.YELLOW + "{0:12}  ".format(state.mode_system.name) +
-                Fore.YELLOW + "{0:10}  ".format(state.mode_flight.name) +
-                Fore.WHITE + "{0:17}  ".format(state.mode_control_flight.name) +
-                Fore.WHITE + "{0:12}  ".format(state.mode_movement.name) +
+                Fore.YELLOW + "{0:12}  ".format(state.modeSystem.name) +
+                Fore.YELLOW + "{0:10}  ".format(state.modeFlight.name) +
+                Fore.WHITE + "{0:17}  ".format(state.modeControlFlight.name) +
+                Fore.WHITE + "{0:12}  ".format(state.modeMovement.name) +
                 Fore.WHITE + "{0:8}  ".format(state.headless.name) +
-                Fore.CYAN + "{0:12}  ".format(state.control_speed) +
-                Fore.CYAN + "{0:17}  ".format(state.sensor_orientation.name) +
+                Fore.CYAN + "{0:12}  ".format(state.controlSpeed) +
+                Fore.CYAN + "{0:17}  ".format(state.sensorOrientation.name) +
                 Fore.GREEN + "{0:7}".format(state.battery) + Style.RESET_ALL)
                 
 
 
-    def event_motion(self, motion):
+    def eventMotion(self, motion):
 
         print(  "* Motion " +
-                Fore.YELLOW + "{0:8}".format(motion.accel_x) +
-                Fore.YELLOW + "{0:8}".format(motion.accel_y) +
-                Fore.YELLOW + "{0:8}".format(motion.accel_z) +
-                Fore.WHITE + "{0:8}".format(motion.gyro_roll) +
-                Fore.WHITE + "{0:8}".format(motion.gyro_pitch) +
-                Fore.WHITE + "{0:8}".format(motion.gyro_yaw) +
-                Fore.CYAN + "{0:8}".format(motion.angle_roll) +
-                Fore.CYAN + "{0:8}".format(motion.angle_pitch) +
-                Fore.CYAN + "{0:8}".format(motion.angle_yaw) + Style.RESET_ALL)
+                Fore.YELLOW + "{0:8}".format(motion.accelX) +
+                Fore.YELLOW + "{0:8}".format(motion.accelY) +
+                Fore.YELLOW + "{0:8}".format(motion.accelZ) +
+                Fore.WHITE + "{0:8}".format(motion.gyroRoll) +
+                Fore.WHITE + "{0:8}".format(motion.gyroPitch) +
+                Fore.WHITE + "{0:8}".format(motion.gyroYaw) +
+                Fore.CYAN + "{0:8}".format(motion.angleRoll) +
+                Fore.CYAN + "{0:8}".format(motion.anglePitch) +
+                Fore.CYAN + "{0:8}".format(motion.angleYaw) + Style.RESET_ALL)
 
 
-    def event_card_range(self, card_range):
+    def eventCardRange(self, cardRange):
         
         print(  "* RawCardRange " +
-                Fore.RED    + "{0:6}".format(card_range.range[0][0][0]) +
-                Fore.RED    + "{0:6}".format(card_range.range[0][0][1]) +
-                Fore.GREEN  + "{0:6}".format(card_range.range[0][1][0]) +
-                Fore.GREEN  + "{0:6}".format(card_range.range[0][1][1]) +
-                Fore.BLUE   + "{0:6}".format(card_range.range[0][2][0]) +
-                Fore.BLUE   + "{0:6}".format(card_range.range[0][2][1]) +
-                Fore.RED    + "{0:6}".format(card_range.range[1][0][0]) +
-                Fore.RED    + "{0:6}".format(card_range.range[1][0][1]) +
-                Fore.GREEN  + "{0:6}".format(card_range.range[1][1][0]) +
-                Fore.GREEN  + "{0:6}".format(card_range.range[1][1][1]) +
-                Fore.BLUE   + "{0:6}".format(card_range.range[1][2][0]) +
-                Fore.BLUE   + "{0:6}".format(card_range.range[1][2][1]) + Style.RESET_ALL)
+                Fore.RED    + "{0:6}".format(cardRange.range[0][0][0]) +
+                Fore.RED    + "{0:6}".format(cardRange.range[0][0][1]) +
+                Fore.GREEN  + "{0:6}".format(cardRange.range[0][1][0]) +
+                Fore.GREEN  + "{0:6}".format(cardRange.range[0][1][1]) +
+                Fore.BLUE   + "{0:6}".format(cardRange.range[0][2][0]) +
+                Fore.BLUE   + "{0:6}".format(cardRange.range[0][2][1]) +
+                Fore.RED    + "{0:6}".format(cardRange.range[1][0][0]) +
+                Fore.RED    + "{0:6}".format(cardRange.range[1][0][1]) +
+                Fore.GREEN  + "{0:6}".format(cardRange.range[1][1][0]) +
+                Fore.GREEN  + "{0:6}".format(cardRange.range[1][1][1]) +
+                Fore.BLUE   + "{0:6}".format(cardRange.range[1][2][0]) +
+                Fore.BLUE   + "{0:6}".format(cardRange.range[1][2][1]) + Style.RESET_ALL)
 
 
-    def event_card_raw(self, card_raw):
+    def eventCardRaw(self, cardRaw):
 
         print(  "* RawCard " +
-                Fore.RED    + "{0:5}".format(card_raw.rgb_raw[0][0]) +
-                Fore.GREEN  + "{0:5}".format(card_raw.rgb_raw[0][1]) +
-                Fore.BLUE   + "{0:5}".format(card_raw.rgb_raw[0][2]) +
-                Fore.RED    + "{0:5}".format(card_raw.rgb_raw[1][0]) +
-                Fore.GREEN  + "{0:5}".format(card_raw.rgb_raw[1][1]) +
-                Fore.BLUE   + "{0:5}".format(card_raw.rgb_raw[1][2]) +
-                Fore.RED    + "{0:4}".format(card_raw.rgb[0][0]) +
-                Fore.GREEN  + "{0:4}".format(card_raw.rgb[0][1]) +
-                Fore.BLUE   + "{0:4}".format(card_raw.rgb[0][2]) +
-                Fore.RED    + "{0:4}".format(card_raw.rgb[1][0]) +
-                Fore.GREEN  + "{0:4}".format(card_raw.rgb[1][1]) +
-                Fore.BLUE   + "{0:4}".format(card_raw.rgb[1][2]) +
-                Fore.RED    + "{0:4}".format(card_raw.hsvl[0][0]) +
-                Fore.GREEN  + "{0:4}".format(card_raw.hsvl[0][1]) +
-                Fore.BLUE   + "{0:4}".format(card_raw.hsvl[0][2]) +
-                Fore.BLUE   + "{0:4}".format(card_raw.hsvl[0][3]) +
-                Fore.RED    + "{0:4}".format(card_raw.hsvl[1][0]) +
-                Fore.GREEN  + "{0:4}".format(card_raw.hsvl[1][1]) +
-                Fore.BLUE   + "{0:4}".format(card_raw.hsvl[1][2]) +
-                Fore.BLUE   + "{0:4}".format(card_raw.hsvl[1][3]) +
-                Fore.CYAN   + "{0:14}".format(card_raw.color[0].name) +
-                Fore.CYAN   + "{0:14}".format(card_raw.color[1].name) +
-                Fore.CYAN   + "{0:14}".format(card_raw.card.name) + Style.RESET_ALL)
+                Fore.RED    + "{0:5}".format(cardRaw.rgbRaw[0][0]) +
+                Fore.GREEN  + "{0:5}".format(cardRaw.rgbRaw[0][1]) +
+                Fore.BLUE   + "{0:5}".format(cardRaw.rgbRaw[0][2]) +
+                Fore.RED    + "{0:5}".format(cardRaw.rgbRaw[1][0]) +
+                Fore.GREEN  + "{0:5}".format(cardRaw.rgbRaw[1][1]) +
+                Fore.BLUE   + "{0:5}".format(cardRaw.rgbRaw[1][2]) +
+                Fore.RED    + "{0:4}".format(cardRaw.rgb[0][0]) +
+                Fore.GREEN  + "{0:4}".format(cardRaw.rgb[0][1]) +
+                Fore.BLUE   + "{0:4}".format(cardRaw.rgb[0][2]) +
+                Fore.RED    + "{0:4}".format(cardRaw.rgb[1][0]) +
+                Fore.GREEN  + "{0:4}".format(cardRaw.rgb[1][1]) +
+                Fore.BLUE   + "{0:4}".format(cardRaw.rgb[1][2]) +
+                Fore.RED    + "{0:4}".format(cardRaw.hsvl[0][0]) +
+                Fore.GREEN  + "{0:4}".format(cardRaw.hsvl[0][1]) +
+                Fore.BLUE   + "{0:4}".format(cardRaw.hsvl[0][2]) +
+                Fore.BLUE   + "{0:4}".format(cardRaw.hsvl[0][3]) +
+                Fore.RED    + "{0:4}".format(cardRaw.hsvl[1][0]) +
+                Fore.GREEN  + "{0:4}".format(cardRaw.hsvl[1][1]) +
+                Fore.BLUE   + "{0:4}".format(cardRaw.hsvl[1][2]) +
+                Fore.BLUE   + "{0:4}".format(cardRaw.hsvl[1][3]) +
+                Fore.CYAN   + "{0:14}".format(cardRaw.color[0].name) +
+                Fore.CYAN   + "{0:14}".format(cardRaw.color[1].name) +
+                Fore.CYAN   + "{0:14}".format(cardRaw.card.name) + Style.RESET_ALL)
 
 
 # Parser End
